"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const xstate_1 = require("xstate");
const interpreter_1 = require("xstate/lib/interpreter");
function useMachine(config, options, initialContext) {
    const machine = react_1.useMemo(() => xstate_1.Machine(config, options, initialContext), []);
    const [state, setState] = react_1.useState(machine.initialState);
    const [context, setContext] = react_1.useState(initialContext);
    const service = react_1.useMemo(() => {
        const service = interpreter_1.interpret(machine);
        service.onTransition(setState);
        service.onChange(setContext);
        service.init();
        return service;
    }, [machine]);
    // Stop the service when unmounting.
    react_1.useEffect(() => {
        return () => void service.stop();
    }, [service]);
    return { state, send: service.send, context, service };
}
exports.useMachine = useMachine;
